@@ -76,6 +76,7 @@ public:
 	    *centerSelection,//!< QAction center selected atoms
 	    *hideNotSelection,//!< QAction hide non selected atoms
 	    *unhide,//!< QAction show all previous hidden objects
+	    *invhide,//!< QAction show all previous hidden and hide visible objects 
 	    *grow,//!< QAction grow
 	    *fuse,//!< QAction fuse
 	    *shpm1,//!< QAction show part -N ghost
@@ -108,9 +109,9 @@ public:
 	    *fofcact;//!< QAction toggling Fobs-Fcalc maps.
     int rotze;//!< if not -1 the index of an atom in the rotation center.
     QToolButton    *invertMouseZoom;//!< inverts the mouse direction that zoom on right click.
-	QCheckBox      *lighting,//!< enable lighting on the electron density. 
-	      *niceTrans,//!< draw 6 perspectives for each surface to improve transparent visualization. 
-	      *fillMap;//!< draw maps in filled style.
+    QCheckBox      *lighting,//!< enable lighting on the electron density. 
+                   *niceTrans,//!< draw 6 perspectives for each surface to improve transparent visualization. 
+                   *fillMap;//!< draw maps in filled style.
     QToolButton *rCenter;//!< resets the rotation center
     V3 altemitte;//!<rotation center position
     void initLists();
@@ -141,6 +142,7 @@ signals:
     void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert FLAT restrain to the ins file
     void insertEXYZ(QList<MyAtom> selected); //!< Insert EXYZ restrain to the ins file
     void insertEADP(QList<MyAtom> selected); //!< Insert EADP restrain to the ins file
+    void insertSADI(int selected); //!< Insert SADI restrain to the ins file
     void insertDELU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert DELU restrain to the ins file
     void insertSIMU(double esd1, double st, double dmax, QList<MyAtom> selected, QString resiSpec); //!< Insert SIMU restrain to the ins file
     void insertISOR(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert ISOR restrain to the ins file
@@ -175,6 +177,7 @@ public slots:
     void homeXY();
     void incFontSize();
     void invertSelection();
+    void invertHidden();//!< Toggle visibility of atoms etc
     void Listen();
     void loadOrientation();
     void loadOrientation(QString fn);
@@ -222,7 +225,8 @@ public slots:
     void addDANG(); 
     void addFLAT(); 
     void addEXYZ(); 
-    void addEADP(); 
+    void addEADP();
+    void addSADI();
     void addDELU(); 
     void addSIMU(); 
     void addISOR();
