@@ -372,7 +372,7 @@ void DSREditWindow::mailHome() {
   //! Formating according to RFC 6068
   //! Mac and Windows like to have different mailstrings
   QString mailstring;
-#ifdef Q_WS_WIN32
+#if defined Q_WS_WIN32 || defined Q_OS_WIN
       mailstring = "mailto:dkratzert@gmx.de?"
                    "subject=New%20fragment%20for%20DSR"
                    "&body=Dear%20Daniel,%0D%0A"
@@ -908,8 +908,11 @@ void DSREditWindow::setRestraints() {
     myRestraints.append(line_split);
     num++;
   }
-  if (!badLine)
+  if (!badLine) {
     emit line_error("");
+  } else {
+    return;
+  }
   if (myRestraints[0].isEmpty()) {
     //addButton->setDisabled(true);
     //updateButton->setDisabled(true);
@@ -1135,8 +1138,14 @@ int DSREditWindow::getCharWidth(int numchars) {
   for (int i=1; i<=numchars; i++) {
     buchstaben += "#";
   }
-  return QFontMetrics(this->font()).width(buchstaben);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+  return QFontMetrics(this->font()).horizontalAdvance(buchstaben);
 }
+#else
+    return QFontMetrics(this->font()).width(buchstaben);
+}
+#endif
 
 void DSREditWindow::deleteCurrentFragment(){
   //! delete the currently open fragment
