@@ -203,8 +203,8 @@ void EacGLW::draw(){
   //int pr;
   //glGetIntegerv(GL_CURRENT_PROGRAM,&pr);
   //printf("@@@%d %d \n",pr,mol->g_program);
-  const GLfloat  OBJ_SPE[]   = { 0.8, 0.8, 0.8, 1.0 };  
-  const GLfloat  OBJ_SHIN    =  32.0;               
+  const GLfloat  OBJ_SPE[]   = { 0.8f, 0.8f, 0.8f, 1.0f };  
+  const GLfloat  OBJ_SHIN    =  32.0f;               
   glMaterialfv( GL_FRONT_AND_BACK, GL_SPECULAR,             OBJ_SPE  );
   glEnable     ( GL_COLOR_MATERIAL ) ;
   glColorMaterial ( GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE ) ;    
@@ -245,8 +245,6 @@ void EacGLW::draw(){
   glPopMatrix();
 }
 void EacGLW::initializeGL(){
-  myquad=mol->q;
-  mol->q=gluNewQuadric();
   glEnable(GL_LINE_SMOOTH);  
   glHint(GL_LINE_SMOOTH_HINT,GL_NICEST);
 
@@ -259,9 +257,9 @@ void EacGLW::initializeGL(){
   //glEnable(GL_POLYGON_SMOOTH);   
   myFont= QFont("Arial", 18, -1, false);
   const GLfloat  position[] = {100.0f, 100.0f,100.0f,0.0f};
-  const GLfloat  diffuse[]  = { 1.0, 1.0, 1.0, 1.0 };
-  const GLfloat  specular[] = { 1.0, 0.9, 0.9, 1.0 };
-  const GLfloat  ambient[]  = { 0.4, 0.4, 0.4, 1.0 };
+  const GLfloat  diffuse[]  = { 1.0f, 1.0f, 1.0f, 1.0f };
+  const GLfloat  specular[] = { 1.0f, 0.9f, 0.9f, 1.0f };
+  const GLfloat  ambient[]  = { 0.4f, 0.4f, 0.4f, 1.0f };
 
   glLightModeli(  GL_LIGHT_MODEL_LOCAL_VIEWER, 1 );
 
@@ -273,6 +271,7 @@ void EacGLW::initializeGL(){
   glLightfv( GL_LIGHT1, GL_POSITION, position );
   glLightfv( GL_LIGHT1, GL_DIFFUSE,  diffuse );  
   glLightfv( GL_LIGHT1, GL_AMBIENT,  ambient );
+  glLightModeli(  GL_LIGHT_MODEL_TWO_SIDE, 1);
 
   glLightfv( GL_LIGHT2, GL_DIFFUSE,  diffuse );  
   mol->adpwall_plaid=bindTexture(QImage(QString(":/icons/adpwall.png")),GL_TEXTURE_2D);
@@ -304,7 +303,7 @@ void EacGLW::initializeGL(){
   glMaterialf(  GL_FRONT_AND_BACK, GL_SHININESS,           OBJ_SHIN );
   glShadeModel( GL_SMOOTH );
   glEnable(GL_NORMALIZE);
-  glClearColor(0.4,0.4,0.4,1.0);
+  glClearColor(0.4f,0.4f,0.4f,1.0f);
   glEnable(GL_DEPTH_TEST );
   glDepthFunc(GL_LEQUAL);
   gluLookAt(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
@@ -323,7 +322,7 @@ void EacGLW::resizeGL(int width, int height){
 }
 
 void EacGLW::paintGL(){
-  glClearColor(0.8,0.8,0.8,1.0);
+  glClearColor(0.8f,0.8f,0.8f,1.0f);
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
   glViewport(0, 0, QGLWidget::width(), QGLWidget::height());        
   glGetIntegerv(GL_VIEWPORT, vp);
@@ -1101,7 +1100,8 @@ EacDlg::EacDlg(Molecule *externMole){
   }else{
     mol->useShaders=false;
     shaderUse->setChecked(mol->useShaders); 
-    shaderUse->setDisabled(true); 
+    //shaderUse->setDisabled(true); 
+    connect(shaderUse ,SIGNAL(toggled(bool)),this,SLOT(checkShader(bool)));
   }  
   glt->addWidget(shaderUse);
   globalStuff->setLayout(glt);
@@ -1234,18 +1234,11 @@ void EacDlg::doMulti(){
 MultiStyle::MultiStyle(Molecule *externMole){
   mol=externMole;
   setWindowTitle("Multiple Elements Styler");  
-  QStringList psel;
-  psel << "H" << "He" << "Li" << "Be" << "B" << "C" << "N" << "O" << "F" << "Ne" << "Na" << "Mg" << "Al" << "Si" << "P" << "S" << "Cl" << "Ar" <<
-	  "K" << "Ca" << "Sc" << "Ti" << "V" << "Cr" << "Mn" << "Fe" << "Co" << "Ni" << "Cu" << "Zn" << "Ga" << "Ge" << "As" << "Se" << "Br" << "Kr" <<
-	  "Rb" << "Sr" << "Y" << "Zr" << "Nb" << "Mo" << "Tc" << "Ru" << "Rh" << "Pd" << "Ag" << "Cd" << "In" << "Sn" << "Sb" << "Te" << "I" << "Xe" <<
-	  "Cs" << "Ba" <<  "La" << "Ce" << "Pr" << "Nd" << "Pm" << "Sm" << "Eu" << "Gd" << "Tb" << "Dy" << "Ho" << "Er" << "Tm" << "Yb" << "Lu" <<
-	  "Hf" << "Ta" << "W" << "Re" << "Os" << "Ir" << "Pt" << "Au" << "Hg" << "Tl" << "Pb" << "Bi" << "Po" << "At" << "Rn" << "Fr" << "Ra" <<
-	  "Ac" << "Th" << "Pa" << "U" << "Np" << "Pu" << "Am" << "Cm" << "Bk" << "Cf" << "Es" << "Fm" << "Md" << "No" << "Lr" << "Ku" << "Ha" << "Rf" << "Ns" << "Hs" << "Mt";
   start = new QComboBox();
   end = new QComboBox();
-  start->addItems(psel);
+  start->addItems(mol->thepse());
   start->setCurrentIndex(2);
-  end->addItems(psel);
+  end->addItems(mol->thepse());
   end->setCurrentIndex(93);
   QLabel *staL =new QLabel("From: "); 
   QLabel *endL =new QLabel("To: "); 
@@ -1295,7 +1288,6 @@ void MultiStyle::checkBall(){
 
 void EacDlg::reject(){
   eacGLW->timer->stop();
-  mol->q=eacGLW->myquad;
   /*
      int i=eacGLW->xd.at(0).an;
   //  extern molekul mol; 
