@@ -564,7 +564,7 @@ void GraphSceene::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
 	 y= mouseEvent->scenePos().y();
 //  qDebug()<<mouseEvent->buttons()<< mouseEvent->buttonDownScreenPos (Qt::LeftButton);
   if (mouseEvent->buttons()&Qt::LeftButton){
-    QPointF oli,ure;
+    QPointF oli,ure;//oben links , unten rechts
     oli.setX(qMin(selStart.x(),selEnd.x()));
     oli.setY(qMin(selStart.y(),selEnd.y()));
     ure.setX(qMax(selStart.x(),selEnd.x()));
@@ -583,7 +583,8 @@ void GraphSceene::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
     }
     selStart = mouseEvent->buttonDownScenePos (Qt::LeftButton);
     selEnd =   mouseEvent->scenePos();
-    if (selStart!=QPointF(0,0)) selEckt->setRect(QRectF(selStart,selEnd));
+    //if (selStart!=QPointF(0,0)) selEckt->setRect(QRectF(selStart,selEnd));
+    if (selStart!=QPointF(0,0)) selEckt->setRect(QRectF(oli,ure));
     drin.clear();
    // qDebug()<<"End"<<selEnd;
   }else{	
