@@ -26,8 +26,8 @@ HistoryWidget::HistoryWidget(QWidget *parent) :
 }
 
 void HistoryWidget::mouseMoveEvent(QMouseEvent *event){
-    if (event->pos().y()<6) {
-        emit message("");
+    if (event->pos().y()<(fh+3)) {
+        emit message("The Savehistory has an entry every time the file was saved by or before the refinement");
         return;
     }
     if  (RWerte.isEmpty()) return;
@@ -140,6 +140,7 @@ void HistoryWidget::mousePressEvent ( QMouseEvent * event ){
       delete menu;
   }
   if (event->buttons() & Qt::LeftButton){
+    if (event->pos().y()<(fh+3)) {emit saveHist(); return;}
     if (dirname.contains(QRegExp(".res$",Qt::CaseInsensitive))){
       QString insname =dirname;
       insname.replace(QRegExp(".res$",Qt::CaseInsensitive),".ins");
@@ -359,12 +360,12 @@ QColor HistoryWidget::farbverlauf(double wrt){
   int rot,gruen,blau,alpha;
   int lauf=0;
   const float farbe[6][4]={
-    {0.0,0.6,0.0,1.0},
-    {0.0,0.6,1.0,1.0},
-    {0.0,0.0,1.0,1.0},
-    {0.7,0.6,0.0,1.0},
-    {0.7,0.0,1.0,1.0},
-    {0.7,0.0,0.0,1.0}};
+    {0.0f,0.6f,0.0f,1.0f},
+    {0.0f,0.6f,1.0f,1.0f},
+    {0.0f,0.0f,1.0f,1.0f},
+    {0.7f,0.6f,0.0f,1.0f},
+    {0.7f,0.0f,1.0f,1.0f},
+    {0.7f,0.0f,0.0f,1.0f}};
   float nwrt=(wrt)/(100);
   nwrt=(nwrt>=1.0)?0.99999:nwrt;
   nwrt=(nwrt<=0.0)?0.00001:nwrt;
@@ -384,7 +385,7 @@ void HistoryWidget::paintEvent(QPaintEvent *event){
   for (int i=0; i<RWerte.size(); i++){
     x = qMax(RWerte.at(i),x);
     if (FreeWerte.contains(i))
-        x = qMax(FreeWerte.value(i),x);
+      x = qMax(FreeWerte.value(i),x);
   }
   QPainter p(this);
   setMinimumWidth(qMax(p.fontMetrics().width(QString("%1").arg(x,4,'f',3))*RWerte.size(),maxwid));
@@ -393,39 +394,32 @@ void HistoryWidget::paintEvent(QPaintEvent *event){
   p.setPen(Qt::black);
 
   if  (RWerte.isEmpty()) return;
-  int h = height(), w = width() / RWerte.size(),fh=p.fontMetrics().height();
-  p.drawText(0,0,width(),fh,Qt::AlignLeft,QString("Total size of history on disk: %1%2")
-             .arg((gesamtGr/(1024*1024))?(double)gesamtGr/(1024*1024):(double)gesamtGr/1024,7,'f',1)
-             .arg((gesamtGr/(1024*1024))?"MB":"kB"));
+  int h = height(), w = width() / RWerte.size();
+  fh=p.fontMetrics().height();
+  //save History
+  p.setBrush(QBrush(QColor("#eeeecc")));
+  p.drawRect(0,0,width(),fh);
+  p.drawText(0,0,width(),fh,Qt::AlignLeft,QString("Alternatively open the SaveHistory! (click here)"));//
+  //
+  p.drawText(0,fh,width(),fh,Qt::AlignLeft,QString("Total size of history on disk: %1%2")
+      .arg((gesamtGr/(1024*1024))?(double)gesamtGr/(1024*1024):(double)gesamtGr/1024,7,'f',1)
+      .arg((gesamtGr/(1024*1024))?"MB":"kB"));
   for (int i = 0; i < RWerte.size(); i++){
-/*    if (saveFilesList.at(i)==dirname){
-    p.setBrush(QBrush(QColor("#ffddaa")));
-    int W=qMax(p.fontMetrics().width("open save"),w);
-    p.drawRoundedRect(i*w-((W-w+2)),0,W,2*fh+2,5.0,5.0);
-    QPoint drei[3];
-    drei[0]= QPoint((i*w+w/3),(2*fh+2));
-    drei[1]= QPoint((i*w+2*w/3),(2*fh+2));
-    drei[2]= QPoint((i*w+w/2),qMax((int)(h-(RWerte.at(i)/25*h))-1,0)-fh);
-    p.drawPolygon(drei,3);
-    p.setPen(Qt::black);
-    p.drawText(i*w-((W-w+2)),0,W, fh,Qt::AlignCenter,QString("open save"));
-    p.drawText(i*w-((W-w+2)),fh+2,W, fh,Qt::AlignCenter,QString("history"));
-    }*/
-      if (FreeWerte.contains(i)){
+    if (FreeWerte.contains(i)){
       p.setBrush(QBrush(farbverlauf(FreeWerte.value(i)*3)));
       p.drawRect(i*w+5,qMax((int)(h-(FreeWerte.value(i)/25*h))-1,0),w*0.95-5,qMin((int)(FreeWerte.value(i)/25*h),h-2));
     }
     p.setBrush(QBrush(farbverlauf(RWerte.at(i)*3)));
     p.drawRect(i*w,qMax((int)(h-(RWerte.at(i)/25*h))-1,0),w*0.9,qMin((int)(RWerte.at(i)/25*h),h-2));
-      if (FreeWerte.contains(i)){
-          p.drawText(i*w, qMax((int)(h-(FreeWerte.value(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
-                  .arg(RWerte.at(i),4,'f',2));
+    if (FreeWerte.contains(i)){
+      p.drawText(i*w, qMax((int)(h-(FreeWerte.value(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+          .arg(RWerte.at(i),4,'f',2));
 
-          p.drawText(i*w, qMax((int)(h-((FreeWerte.value(i))/25*h))-fh,fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
-                  .arg(FreeWerte.value(i),4,'f',2));
-      }else
-    p.drawText(i*w, qMax((int)(h-(RWerte.at(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
-		    .arg(RWerte.at(i),4,'f',2));
+      p.drawText(i*w, qMax((int)(h-((FreeWerte.value(i))/25*h))-fh,fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+          .arg(FreeWerte.value(i),4,'f',2));
+    }else
+      p.drawText(i*w, qMax((int)(h-(RWerte.at(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+          .arg(RWerte.at(i),4,'f',2));
   }
   event->accept();
   //p.drawText(0,0,p.fontMetrics().width("1234567890"),p.fontMetrics().height(),Qt::AlignLeft,QString("%1 %2").arg(h).arg(w));
@@ -436,6 +430,7 @@ bool HistoryWidget::event(QEvent *event){
   if (event->type() == QEvent::ToolTip) {
     QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
     QPoint da = helpEvent->pos();
+    if (da.y()<(fh+3))return true;
     if  (RWerte.isEmpty()) return true;
     int w = width() / RWerte.size();
     int index = da.x() / w;
@@ -445,31 +440,31 @@ bool HistoryWidget::event(QEvent *event){
     fcfname.replace(fcfname.size()-3,3,"fcf");
     bool fcfda=QFile::exists(fcfname);
     if (FreeWerte.contains(index)){
-        QToolTip::showText(helpEvent->globalPos(),
-        QString("<b>%4:</b><br> R1(Free) = <b>%9</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
-                        .arg(RWerte.at(index))
-                        .arg(RallWerte.at(index))
-                        .arg(((index<gooddata.size())&&(index<parameters.size()))  ?(double) gooddata.at(index) / parameters.at(index):0)
-                        .arg((index<saveFilesList.size())?saveFilesList.at(index):0)
-                        .arg((index<dateTimesList.size())?dateTimesList.at(index).toString("d MMM yyyy - hh:mm:ss"):"??")
-                        .arg((index<gooddata.size())?gooddata.at(index):0)
-                        .arg((index<parameters.size())?parameters.at(index):0)
-                        .arg((fcfda)?"Yes":"No")
-                        .arg(FreeWerte.value(index)));
+      QToolTip::showText(helpEvent->globalPos(),
+          QString("<b>%4:</b><br> R1(Free) = <b>%9</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
+          .arg(RWerte.at(index))
+          .arg(RallWerte.at(index))
+          .arg(((index<gooddata.size())&&(index<parameters.size()))  ?(double) gooddata.at(index) / parameters.at(index):0)
+          .arg((index<saveFilesList.size())?saveFilesList.at(index):0)
+          .arg((index<dateTimesList.size())?dateTimesList.at(index).toString("d MMM yyyy - hh:mm:ss"):"??")
+          .arg((index<gooddata.size())?gooddata.at(index):0)
+          .arg((index<parameters.size())?parameters.at(index):0)
+          .arg((fcfda)?"Yes":"No")
+          .arg(FreeWerte.value(index)));
 
     }else
-    QToolTip::showText(helpEvent->globalPos(),
-    QString("<b>%4:</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
-                    .arg(RWerte.at(index))
-                    .arg(RallWerte.at(index))
-                    .arg(((index<gooddata.size())&&(index<parameters.size()))  ?(double) gooddata.at(index) / parameters.at(index):0)
-                    .arg((index<saveFilesList.size())?saveFilesList.at(index):0)
-                    .arg((index<dateTimesList.size())?dateTimesList.at(index).toString("d MMM yyyy - hh:mm:ss"):"??")
-                    .arg((index<gooddata.size())?gooddata.at(index):0)
-                    .arg((index<parameters.size())?parameters.at(index):0)
-		    .arg((fcfda)?"Yes":"No")
-		    
-		    );
+      QToolTip::showText(helpEvent->globalPos(),
+          QString("<b>%4:</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
+          .arg(RWerte.at(index))
+          .arg(RallWerte.at(index))
+          .arg(((index<gooddata.size())&&(index<parameters.size()))  ?(double) gooddata.at(index) / parameters.at(index):0)
+          .arg((index<saveFilesList.size())?saveFilesList.at(index):0)
+          .arg((index<dateTimesList.size())?dateTimesList.at(index).toString("d MMM yyyy - hh:mm:ss"):"??")
+          .arg((index<gooddata.size())?gooddata.at(index):0)
+          .arg((index<parameters.size())?parameters.at(index):0)
+          .arg((fcfda)?"Yes":"No")
+
+          );
     return true;
   }
   return QWidget::event(event);
