@@ -24,7 +24,9 @@ void mh(QtMsgType type, const QMessageLogContext &context, const QString &msg) {
   QByteArray localMsg = msg.toLocal8Bit();
     QString pth=QDir::homePath()+"/ShelXle_message.txt";
     FILE *er=fopen(pth.toStdString().c_str(),"at");
-    fprintf(er,"======%s\n%s\n======\n",QDateTime::currentDateTime().toString().utf16(),localMsg.constData());
+    fprintf(er,"======%s\n%s\n======\n",
+        QDateTime::currentDateTime().toString().toStdString().c_str(),
+        localMsg.constData());
     fclose(er);
     if (strstr(localMsg.constData(),"QGLShader::link:")!=NULL) {
       printf("%s\n",localMsg.constData());fflush(stdout);
@@ -42,31 +44,32 @@ void mh(QtMsgType type, const QMessageLogContext &context, const QString &msg) {
   switch (type) {
     case QtDebugMsg:
       fprintf(stderr, "Debug: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC
+// Q_WS_* was droppen in QT5 in favor of Q_OS_*
+#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
     QMessageBox::information(0,"information",msg);
 #endif
       break;
     case QtInfoMsg:
       fprintf(stderr, "Info: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC
+#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
     QMessageBox::information(0,"information",msg);
 #endif
       break;
     case QtWarningMsg:
       fprintf(stderr, "Warning: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC
+#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
     QMessageBox::warning(0,"warning",msg);
 #endif
       break;
     case QtCriticalMsg:
       fprintf(stderr, "Critical: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  || defined Q_WS_MAC
+#if defined Q_WS_WIN  || defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
     QMessageBox::critical(0,"critical",msg);
 #endif
       break;
     case QtFatalMsg:
       fprintf(stderr, "Fatal: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  || defined Q_WS_MAC
+#if defined Q_WS_WIN  || defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
     QMessageBox::critical(0,"fatal",msg);
 #endif
       abort();
